Tutorials
=========

.. toctree::
   :caption: Index
   :maxdepth: 1

   tutorials/00.schunk-basics
   tutorials/01.schunk-slicing_and_beyond
   tutorials/02.ndarray-basics
   tutorials/10.ucodecs-ufilters
   tutorials/11.prefilters
   tutorials/12.postfilters
